# CSS Color Adjustment Module Level 1

## Editor’s Draft, 1 January 1970

Specification Metadata

This version:
  https://drafts.csswg.org/css-color-adjust-1/
Latest published version:
  https://www.w3.org/TR/css-color-adjust-1/
Previous Versions:
  https://www.w3.org/TR/2019/WD-css-color-adjust-1-20190521/
  https://www.w3.org/TR/2019/WD-css-color-adjust-1-20190521/
Editors:
  Elika J. Etemad / fantasai (Invited Expert)
  Rossen Atanassov (Microsoft)
  Rune Lillesveen (Google)
  Tab Atkins Jr. (Google)
Issue Tracking:
  GitHub Issues
Suggest an Edit for this Spec:
  GitHub Editor

Copyright © 1970 W3C® (MIT, ERCIM, Keio, Beihang). W3C liability, trademark and permissive document license rules apply.

## Abstract

This module introduces a model and controls over automatic color adjustment by the user agent to handle user preferences, such as "Dark Mode", contrast adjustment, or specific desired color schemes.

CSS is a language for describing the rendering of structured documents (such as HTML and XML) on screen, on paper, etc.

## Status of this document

This is a public copy of the editors’ draft. It is provided for discussion only and may change at any moment. Its publication here does not imply endorsement of its contents by W3C. Don’t cite this document other than as work in progress.

GitHub Issues are preferred for discussion of this specification. When filing an issue, please put the text “css-color-adjust” in the title, preferably like this: “[css-color-adjust] …summary of comment…”. All issues and comments are archived, and there is also a historical archive.

This document was produced by the CSS Working Group.

This document was produced by a group operating under the W3C Patent Policy. W3C maintains a public list of any patent disclosures made in connection with the deliverables of the group; that page also includes instructions for disclosing a patent. An individual who has actual knowledge of a patent which the individual believes contains Essential Claim(s) must disclose the information in accordance with section 6 of the W3C Patent Policy.

This document is governed by the 1 March 2019 W3C Process Document.

## 1. Introduction

## 2. Preferred Color Schemes

Operating systems and user agents often give users the ability to choose their preferred color schemes for user interface elements. These are typically reflected in the user agent’s rendering of its navigation interface as well as in-page interface elements such as form controls and scrollbars, and are expected to also be reflected in the values of the CSS system colors.

Users on some systems can also indicate a preference in the color scheme of the pages they view, requesting that the author adapt the page to those color preferences. (It is not required to express a preference; users can have preferences for operating system interface colors that they do not want imposed on pages.) The most common preferences are a choice of “Light” vs “Dark” (or “Day Mode” vs “Night Mode”) color schemes, rendering things as mostly light- or dark-colored backgrounds, and with dark- or light-colored foregrounds (text, icons). This module, together with Media Queries Level 5, defines controls to enable color scheme negotiation for "light" and "dark" color schemes (and no preference).

To enable pages to adapt to the user’s preferred color scheme, user agents will match the prefers-color-scheme media query to the user’s preferred color scheme.

Additionally, if the author has indicated that the page can support this color scheme (see color-scheme), the user agent must match the following to the user’s preferred color scheme:

- the initial color of the background canvas find what we name this in other specs, the initial value of the color property, and the system colors

- the default colors of scrollbars and other interaction UI

- the default colors of form controls and other "specially-rendered" elements

- the default colors of other browser-provided UI, such as "spellcheck" underlines

User agents may support additional color schemes, however CSS does not support negotiation of additional color schemes: user agents should pursue standardization of these schemes, so that prefers-color-scheme and color-scheme can reflect the additional values.

Note: Aside from the small list of adjustments given above, user agents generally do not further adjust a page to match the user’s preferred color scheme, because the chance of accidentally ruining a page is too high. However, when particular color choices are required by the user (for accessibility reasons, for example), more invasive changes might be applied; see § 3 Forced Color Schemes: the forced-color-adjust property.

### 2.1. Opting Into a Preferred Color Scheme: the color-scheme property

Name: | color-scheme
Value: | normal | [ light | dark | <custom-ident> ]+ | only && light
Initial: | normal
Applies to: | all elements
Inherited: | yes
Percentages: | n/a
Computed value: | the keyword normal, or optional only keyword and ordered list of specified color scheme keywords
Canonical order: | per grammar
Animation type: | discrete

The color-scheme property allows an element to indicate which color schemes it is comfortable being rendered with. These values are negotiated with the users preferences, resulting in a chosen color scheme that affects UI things such as the default colors of form controls and scrollbars as well as the used values of the CSS system colors. Its values are defined as follows:

normal

  Indicates that the element isn’t aware of color schemes at all, and so the element should be rendered with the browser’s default color scheme.

[ light | dark | <custom-ident> ]+

  Indicates that the element is aware of and can handle the listed color schemes, and expresses an ordered preference between them. (See § 2.2 Finding the Used Color Scheme for details on how this choice is resolved.)

  light represents a "light" color scheme, with light background colors and dark foreground colors. dark represents the opposite, with dark background colors and light foreground colors.

  Note: Providing both keywords indicates that the first scheme is preferred, but the second is also acceptable if the user prefers it instead.

  <custom-ident> values are meaningless, and exist only for future compatibility, so that future added color schemes do not invalidate the color-scheme declaration in legacy user agents. User agents must not interpret any <custom-ident> values as having a meaning; any additional recognized color schemes must be explicitly added to this property’s grammar. To avoid confusion, authoring tutorials and references should omit it from their materials.

  only, normal, light, and dark are not valid <custom-ident>s in this property.

  Repeating a keyword, such as color-scheme: light light, is valid but has no additional effect beyond what the first instance of the keyword provides.

only

  If provided, only indicates that the element must be rendered with one of the specified color schemes, if possible, even if the user’s preference is for a different color scheme.

  Per spec, only can only be used with light. Apple’s implementation allows it with dark as well. The concern with only dark is that pages won’t consider UAs that can’t support dark schemes, and will thus render brokenly. This value might be expanded to all schemes or removed entirely depending on further consideration.

  Authors should not use this value, and should instead ensure that their page renders well with whatever color scheme the user prefers (using the prefers-color-scheme media query to adjust styles accordingly). This keyword is provided only for the rare cases where that might not be reasonably possible, and using a different color scheme would render the element difficult or impossible to use.

  Note that user agents are not required to support any particular color scheme, so using only to indicate a required color scheme is still not guaranteed to have any effect on the rendering of the element.

Note: “Light” and “Dark” modes are not specific color palettes. For example, both a stark black-on-white scheme and a sepia dark-on-tan scheme would be considered “Light” color schemes. To ensure particular foreground or background colors, they need to be specified explicitly.

### 2.2. Finding the Used Color Scheme

To find the used color scheme for an element el:

1. Let scheme be the keyword matching prefers-color-scheme.

2. If the computed value of color-scheme on el contains scheme, return scheme.

3. If the computed value of color-scheme on el contains the only keyword or scheme is no-preference, and at least one color scheme indicated in color-scheme is supported by the user agent, return the first keyword, in specified order, that is supported by the user agent.

4. Otherwise, return no-preference.

For each element, find the used color scheme for that element. If the used color scheme is no-preference, the element must be rendered with the user agent’s default color scheme. (For Web compatibility, this should be a "light" color scheme.) Otherwise, the element must be rendered with the used color scheme.

Note: This algorithm ensures that if the user prefers a non-default color scheme, it will only be used if the page claims to support it. This ensures that legacy pages, written before color scheme preferences were exposed, do not change behavior.

For all elements, rendering with a color scheme should affect the colors used in all browser-provided UI for the element—e.g. scrollbars, spellcheck underlines, form controls, etc.—to match with the intent of the color scheme.

For the root element of a page, rendering with a color scheme additionally must affect the background of the canvas, the initial value of the color property, and the system colors, and should affect the page’s scrollbars.

### 2.3. The "color-scheme" `meta` value

To aid user agents in rendering the page background with the desired color scheme immediately (rather than waiting for all CSS in the page to load), a color-scheme value can also be provided in a `meta` element.

If any `meta` elements are inserted into a document or removed from a document, or existing `meta` elements have their `name` or `content` attributes changed, user agents must run the following algorithm:

1. Let candidate elements be the list of all `meta` elements that meet the following criteria, in tree order:

   - the element is in a document tree

   - the element has a `name` attribute, whose value is an ASCII case-insensitive match for `color-scheme`

   - the element has a `content` attribute, whose value is not the empty string

   - the element is a child of the the head element of the document

2. For each element in candidate elements:

   1. If element’s `content` attribute’s value parses as a <color-scheme> value, treat that value as a declaration of the color-scheme property on element’s root, cascaded as a non-CSS presentational hint. Then return.

Note: Because these rules check successive elements until they find a match, an author can provide multiple such values to handle fallback for legacy user agents. Opposite how CSS fallback works for properties, the multiple `meta` elements must be arranged with the legacy values after the newer values.

This algorithm favors the first `meta`, to allow for ASAP rendering with a chosen color scheme. Is that the desired behavior?

## 3. Forced Color Schemes: the forced-color-adjust property

Forced colors mode is an accessibility feature intended to increase the readability of text through color contrast. Individuals with limited vision often find it more comfortable to read content when there is a a particular type of contrast between foreground and background colors.

Operating systems can provide built-in color themes, such as Windows’ high contrast black-on-white and high-contrast white-on-black themes. Users can also customize their own themes, for example to provide low contrast or hue contrast.

In forced colors mode, the user agent enforces the user’s preferred color palette on the page, overriding the author’s chosen colors for specific properties, see § 3.1 Properties Affected by Forced Colors Mode. It may also enforce a “backplate” underneath text (similar to the way backgrounds are painted on the ::selection pseudo-element) to ensure adequate contrast for readability.

To enable pages to adapt to forced colors mode user agents will match the forced-colors media query and must provide the required color palette through the CSS system colors (see [CSS-COLOR-4]). Additionally, if the UA determines (based on Lab lightness), that the canvas color is clearly either dark or light (for some reasonable UA delineation of “dark” or “light”), then it must match the appropriate value of the prefers-color-scheme media query and express a corresponding user preference for color-scheme. This will allow pages that support light/dark color schemes to automatically adjust to more closely match the forced color scheme. Note that medium-lightness forced backgrounds may yield a prefers-color-scheme of no-preference.

### 3.1. Properties Affected by Forced Colors Mode

When forced colors mode is active and forced-color-adjust is auto (see below), the following user origin declarations [CSS-CASCADE-4] are applied to the element:

    color: revert !important;
    fill: revert !important;
    stroke: revert !important;
    text-decoration-color: revert !important;
    text-emphasis-color: revert !important;
    background-color: revert !important;
    border-color: revert !important;
    outline-color: revert !important;
    column-rule-color: revert !important;
    scrollbar-color: revert !important;
    -webkit-tap-highlight-color: revert !important; /* ISSUE: This is not in a spec anywhere! */

    box-shadow: none !important;
    text-shadow: none !important;

Additionally, on on user input controls (except button-like controls) only:

    background-image: none !important;

UA may further tweak these forced colors mode heuristics to provide better user experience.

### 3.2. Opting Out of a Forced Color Scheme: the forced-color-adjust property

Name: | forced-color-adjust
Value: | auto | none
Initial: | auto
Applies to: | all elements
Inherited: | yes
Percentages: | n/a
Computed value: | as specified
Canonical order: | per grammar
Animation type: | discrete

The forced-color-adjust property allows authors to opt particular elements out of forced colors mode, restoring full control over the colors to CSS. Values have the following meanings:

auto

  The element’s colors are automatically adjusted by the UA in forced colors mode.

none

  The element’s colors are not automatically adjusted by the UA in forced colors mode.

  Authors should only use this value when they are themselves adjusting the colors to support the user’s color and contrast needs and need to make changes to the UA’s default adjustments to provide a more appropriate user experience for those elements.

Should this property be merged with color-adjust somehow?

In order to not break SVG content, UAs are expected to add the following rules to their UA style sheet:

    @namespace "http://www.w3.org/2000/svg";
    svg|svg { forced-color-adjust: none; }
    svg|text, svg|foreignObject { forced-color-adjust: auto; }

## 4. Performance-based Color Schemes: the color-adjust property

On most monitors, the color choices that authors make have no significant difference in terms of how the device performs; displaying a document with a white background or a black background is approximately equally easy.

However, some devices have limitations and other qualities that make this assumption untrue. For example, printers tend to print on white paper; a document with a white background thus has to spend no ink on drawing that background, while a document with a black background will have to expend a large amount of ink filling in the background color. This tends to look fairly bad, and sometimes has deleterious physical effects on the paper, not to mention the vastly increased printing cost from expending the extra ink. Even fairly small differences, such as coloring text black versus dark gray, can be quite different when printing, as it switches from using a single black ink to a mixture of cyan, magenta, and yellow ink, resulting in higher ink usage and lower resolution.

As a result, in some circumstances user agents will alter the styles an author specifies in some particular context, adjusting them to be more appropriate for the output device and to accommodate what they assume the user would prefer. However, in some cases the document may be using colors in important, well-thought-out ways that the user would appreciate, and so the document would like some way to hint to the user agent that it might want to respect the page’s color choices. The color-adjust property controls this.

Name: | color-adjust
Value: | economy | exact
Initial: | economy
Applies to: | all elements
Inherited: | yes
Percentages: | N/A
Computed value: | specified keyword
Canonical order: | per grammar
Animation type: | discrete

The color-adjust property provides a hint to the user-agent about how it should treat color and style choices that might be expensive or generally unwise on a given device, such as using light text on a dark background in a printed document. If user agents allow users to control this aspect of the document’s display, the user preference must be respected more strongly than the hint provided by color-adjust. It has the following values:

economy
  The user agent should make adjustments to the page’s styling as it deems necessary and prudent for the output device.

  For example, if the document is being printed, a user agent might ignore any backgrounds and adjust text color to be sufficiently dark, to minimize ink usage.

exact
  This value indicates that the page is using color and styling on the specified element in a way which is important and significant, and which should not be tweaked or changed except at the user’s request.

  For example, a mapping website offering printed directions might "zebra-stripe" the steps in the directions, alternating between white and light gray backgrounds. Losing this zebra-striping and having a pure-white background would make the directions harder to read with a quick glance when distracted in a car.

## 5. Acknowledgements

This specification would not be possible without the development efforts of various color adjustment features at Apple, Google, and Microsoft as well as discussions about print adjustments on www-style. In particular, the CSS Working Group would like to thank: Alison Maher, François Remy, イアンフェッティ

List additional MSFT / Apple / Google people here.

## Conformance

### Document conventions

Conformance requirements are expressed with a combination of descriptive assertions and RFC 2119 terminology. The key words “MUST”, “MUST NOT”, “REQUIRED”, “SHALL”, “SHALL NOT”, “SHOULD”, “SHOULD NOT”, “RECOMMENDED”, “MAY”, and “OPTIONAL” in the normative parts of this document are to be interpreted as described in RFC 2119. However, for readability, these words do not appear in all uppercase letters in this specification.

All of the text of this specification is normative except sections explicitly marked as non-normative, examples, and notes. [RFC2119]

Examples in this specification are introduced with the words “for example” or are set apart from the normative text with `class="example"`, like this:

This is an example of an informative example.

Informative notes begin with the word “Note” and are set apart from the normative text with `class="note"`, like this:

Note, this is an informative note.

Advisements are normative sections styled to evoke special attention and are set apart from other normative text with `<strong class="advisement">`, like this: UAs MUST provide an accessible alternative.

### Conformance classes

Conformance to this specification is defined for three conformance classes:

style sheet
  A CSS style sheet.
renderer
  A UA that interprets the semantics of a style sheet and renders documents that use them.
authoring tool
  A UA that writes a style sheet.

A style sheet is conformant to this specification if all of its statements that use syntax defined in this module are valid according to the generic CSS grammar and the individual grammars of each feature defined in this module.

A renderer is conformant to this specification if, in addition to interpreting the style sheet as defined by the appropriate specifications, it supports all the features defined by this specification by parsing them correctly and rendering the document accordingly. However, the inability of a UA to correctly render a document due to limitations of the device does not make the UA non-conformant. (For example, a UA is not required to render color on a monochrome monitor.)

An authoring tool is conformant to this specification if it writes style sheets that are syntactically correct according to the generic CSS grammar and the individual grammars of each feature in this module, and meet all other conformance requirements of style sheets as described in this module.

### Requirements for Responsible Implementation of CSS

The following sections define several conformance requirements for implementing CSS responsibly, in a way that promotes interoperability in the present and future.

#### Partial Implementations

So that authors can exploit the forward-compatible parsing rules to assign fallback values, CSS renderers must treat as invalid (and ignore as appropriate) any at-rules, properties, property values, keywords, and other syntactic constructs for which they have no usable level of support. In particular, user agents must not selectively ignore unsupported property values and honor supported values in a single multi-value property declaration: if any value is considered invalid (as unsupported values must be), CSS requires that the entire declaration be ignored.

#### Implementations of Unstable and Proprietary Features

To avoid clashes with future stable CSS features, the CSSWG recommends following best practices for the implementation of unstable features and proprietary extensions to CSS.

#### Implementations of CR-level Features

Once a specification reaches the Candidate Recommendation stage, implementers should release an unprefixed implementation of any CR-level feature they can demonstrate to be correctly implemented according to spec, and should avoid exposing a prefixed variant of that feature.

To establish and maintain the interoperability of CSS across implementations, the CSS Working Group requests that non-experimental CSS renderers submit an implementation report (and, if necessary, the testcases used for that implementation report) to the W3C before releasing an unprefixed implementation of any CSS features. Testcases submitted to W3C are subject to review and correction by the CSS Working Group.

Further information on submitting testcases and implementation reports can be found from on the CSS Working Group’s website at http://www.w3.org/Style/CSS/Test/. Questions should be directed to the public-css-testsuite@w3.org mailing list.

## Index

### Terms defined by this specification

- auto, in §3.2
- color-adjust, in §4
- color-scheme, in §2.1
- dark, in §2.1
- economy, in §4
- exact, in §4
- forced-color-adjust, in §3.2
- Forced colors mode, in §3
- light, in §2.1
- none, in §3.2
- normal, in §2.1
- only, in §2.1
- used color scheme, in §2.2

https://drafts.csswg.org/css-cascade-4/#cascade-origin-user Referenced in:

- 3.1. Properties Affected by Forced Colors Mode

https://drafts.csswg.org/css-color-4/#propdef-color Referenced in:

- 2. Preferred Color Schemes
- 2.2. Finding the Used Color Scheme

https://drafts.csswg.org/css-pseudo-4/#selectordef-selection Referenced in:

- 3. Forced Color Schemes: the forced-color-adjust property

https://drafts.csswg.org/css-syntax-3/#css-parse-something-according-to-a-css-grammar Referenced in:

- 2.3. The "color-scheme" meta value

https://drafts.csswg.org/css-values-4/#comb-all Referenced in:

- 2.1. Opting Into a Preferred Color Scheme: the color-scheme property

https://drafts.csswg.org/css-values-4/#mult-one-plus Referenced in:

- 2.1. Opting Into a Preferred Color Scheme: the color-scheme property

https://drafts.csswg.org/css-values-4/#identifier-value Referenced in:

- 2.1. Opting Into a Preferred Color Scheme: the color-scheme property (2) (3) (4) (5)

https://drafts.csswg.org/css-values-4/#comb-one Referenced in:

- 2.1. Opting Into a Preferred Color Scheme: the color-scheme property (2) (3) (4)
- 3.2. Opting Out of a Forced Color Scheme: the forced-color-adjust property
- 4. Performance-based Color Schemes: the color-adjust property

https://dom.spec.whatwg.org/#in-a-document-tree Referenced in:

- 2.3. The "color-scheme" meta value

https://dom.spec.whatwg.org/#concept-tree-root Referenced in:

- 2.3. The "color-scheme" meta value

https://dom.spec.whatwg.org/#concept-tree-order Referenced in:

- 2.3. The "color-scheme" meta value

https://html.spec.whatwg.org/multipage/semantics.html#attr-meta-content Referenced in:

- 2.3. The "color-scheme" meta value (2) (3)

https://html.spec.whatwg.org/multipage/infrastructure.html#insert-an-element-into-a-document Referenced in:

- 2.3. The "color-scheme" meta value

https://html.spec.whatwg.org/multipage/semantics.html#meta Referenced in:

- 2.3. The "color-scheme" meta value (2) (3) (4) (5) (6) (7)

https://html.spec.whatwg.org/multipage/infrastructure.html#remove-an-element-from-a-document Referenced in:

- 2.3. The "color-scheme" meta value

https://infra.spec.whatwg.org/#ascii-case-insensitive Referenced in:

- 2.3. The "color-scheme" meta value

https://drafts.csswg.org/mediaqueries-5/#descdef-media-forced-colors Referenced in:

- 3. Forced Color Schemes: the forced-color-adjust property

https://drafts.csswg.org/mediaqueries-5/#descdef-media-prefers-color-scheme Referenced in:

- 2. Preferred Color Schemes (2)
- 2.1. Opting Into a Preferred Color Scheme: the color-scheme property
- 2.2. Finding the Used Color Scheme
- 3. Forced Color Schemes: the forced-color-adjust property (2)

### Terms defined by reference

- [CSS-CASCADE-4] defines the following terms:
  - user origin
- [CSS-COLOR-4] defines the following terms:
  - color
- [css-pseudo-4] defines the following terms:
  - ::selection
- [css-syntax-3] defines the following terms:
  - parse
- [css-values-4] defines the following terms:
  - &&
  - +
  - <custom-ident>
  - |
- [DOM] defines the following terms:
  - in a document tree
  - root
  - tree order
- [HTML] defines the following terms:
  - content
  - inserted into a document
  - meta
  - removed from a document
- [INFRA] defines the following terms:
  - ascii case-insensitive
- [mediaqueries-5] defines the following terms:
  - forced-colors
  - prefers-color-scheme

## References

### Normative References

[CSS-CASCADE-4]
  Elika Etemad; Tab Atkins Jr.. CSS Cascading and Inheritance Level 4. 28 August 2018. CR. URL: https://www.w3.org/TR/css-cascade-4/
[CSS-COLOR-4]
  Tab Atkins Jr.; Chris Lilley. CSS Color Module Level 4. 5 March 2019. WD. URL: https://www.w3.org/TR/css-color-4/
[CSS-PSEUDO-4]
  Daniel Glazman; Elika Etemad; Alan Stearns. CSS Pseudo-Elements Module Level 4. 25 February 2019. WD. URL: https://www.w3.org/TR/css-pseudo-4/
[CSS-SYNTAX-3]
  Tab Atkins Jr.; Simon Sapin. CSS Syntax Module Level 3. 20 February 2014. CR. URL: https://www.w3.org/TR/css-syntax-3/
[CSS-VALUES-4]
  Tab Atkins Jr.; Elika Etemad. CSS Values and Units Module Level 4. 31 January 2019. WD. URL: https://www.w3.org/TR/css-values-4/
[DOM]
  Anne van Kesteren. DOM Standard. Living Standard. URL: https://dom.spec.whatwg.org/
[HTML]
  Anne van Kesteren; et al. HTML Standard. Living Standard. URL: https://html.spec.whatwg.org/multipage/
[INFRA]
  Anne van Kesteren; Domenic Denicola. Infra Standard. Living Standard. URL: https://infra.spec.whatwg.org/
[MEDIAQUERIES-5]
  Media Queries Level 5 URL: https://drafts.csswg.org/mediaqueries-5/
[RFC2119]
  S. Bradner. Key words for use in RFCs to Indicate Requirement Levels. March 1997. Best Current Practice. URL: https://tools.ietf.org/html/rfc2119

## Property Index

Name | Value | Initial | Applies to | Inh. | %ages | Animation type | Canonical order | Computed value
--- | --- | --- | --- | --- | --- | --- | --- | ---
color-adjust | economy | exact | economy | all elements | yes | N/A | discrete | per grammar | specified keyword
color-scheme | normal | [ light | dark | <custom-ident> ]+ | only && light | normal | all elements | yes | n/a | discrete | per grammar | the keyword normal, or optional only keyword and ordered list of specified color scheme keywords
forced-color-adjust | auto | none | auto | all elements | yes | n/a | discrete | per grammar | as specified

## Issues Index

find what we name this in other specs ↵
Per spec, only can only be used with light. Apple’s implementation allows it with dark as well. The concern with only dark is that pages won’t consider UAs that can’t support dark schemes, and will thus render brokenly. This value might be expanded to all schemes or removed entirely depending on further consideration. ↵
This algorithm favors the first `meta`, to allow for ASAP rendering with a chosen color scheme. Is that the desired behavior? ↵
Should this property be merged with color-adjust somehow? ↵
List additional MSFT / Apple / Google people here. ↵
#propdef-color-scheme Referenced in:

- 2. Preferred Color Schemes (2)
- 2.1. Opting Into a Preferred Color Scheme: the color-scheme property (2) (3) (4)
- 2.2. Finding the Used Color Scheme (2) (3)
- 2.3. The "color-scheme" meta value (2) (3)
- 3. Forced Color Schemes: the forced-color-adjust property

#valdef-color-scheme-normal Referenced in:

- 2.1. Opting Into a Preferred Color Scheme: the color-scheme property (2)

#valdef-color-scheme-light Referenced in:

- 2.1. Opting Into a Preferred Color Scheme: the color-scheme property (2) (3) (4) (5) (6) (7)

#valdef-color-scheme-only Referenced in:

- 2.1. Opting Into a Preferred Color Scheme: the color-scheme property (2) (3) (4) (5)
- 2.2. Finding the Used Color Scheme

#used-color-scheme Referenced in:

- 2.2. Finding the Used Color Scheme (2) (3)

#forced-colors-mode Referenced in:

- 3. Forced Color Schemes: the forced-color-adjust property (2)
- 3.1. Properties Affected by Forced Colors Mode (2)
- 3.2. Opting Out of a Forced Color Scheme: the forced-color-adjust property (2) (3)

#propdef-forced-color-adjust Referenced in:

- 3. Forced Color Schemes: the forced-color-adjust property
- 3.1. Properties Affected by Forced Colors Mode
- 3.2. Opting Out of a Forced Color Scheme: the forced-color-adjust property (2)

#valdef-forced-color-adjust-auto Referenced in:

- 3.1. Properties Affected by Forced Colors Mode

#propdef-color-adjust Referenced in:

- 3.2. Opting Out of a Forced Color Scheme: the forced-color-adjust property
- 4. Performance-based Color Schemes: the color-adjust property (2) (3) (4)